@@ -1,5 +1,4 @@
 # Compass CSS framework config file
-require 'breakpoint'
 
 project_type = :stand_alone
 http_path = "/"
@@ -7,5 +6,5 @@ sass_dir = "scss"
 css_dir = "css"
 line_comments = false
 preferred_syntax = :scss
-output_style = :expanded
+output_style = :nested
 relative_assets = true
